<?php
/*-----------------------------------*
* Proyecto : SAI                    *
* Autor    : Federico A. Ocampo     *
* Desc: Interfaz web de Seleccion   *
*       para Armado de Informes     *
*-----------------------------------*/

//--------------------------------------
require_once 'PostgreClass.php';
require_once "AppConfig.php";
//--------------------------------------


/*****************************************************************************
.::. Clase ObtieneDatos .::.
@Autor:   Federico A. Ocampo
@Email:   federico@mcanet.com.ar
@Empresa: MCAnet
@Descripcion:	Esta clase provee los metodos para obtener, de la base de datos 
				correspondiente, las diferentes tablas. Realiza las consultas 
				necesarias y retorna, por cada consulta, un arreglo con toda la 
				tabla resultado.
*****************************************************************************/
class ObtieneDatosAdmin
{
    var $AppConfig;  //Configuracion de la aplicacion
    var $ManejaBD;   //Clase que administra la conexion con la base de datos
    var $DB_CONNECT_ERROR = "FALLO AL CONECTAR CON LA BASE DE DATOS";
    var $DB_QUERY_NULL    = "La consulta no obtuvo resultados";


    /**
    * Constructor: inicializa las propiedades de la clase
    * Recibe todos los parametros por referencia
    * @param AppConfig Objeto con la configuracion de la aplicacion
    * @param ManejadorBD clase para gestionar la conexion con la base de datos
    */
    function ObtieneDatosAdmin(&$AppConfig, &$ManejadorBaseDatos)
    {
      $this->AppConfig =& $AppConfig;
      $this->ManejaBD  =& $ManejadorBaseDatos;
    }
	
	/*---Leos------------------------------------------------------------------------------*/
	/**
	* Obtiene de la base de datos los datos de la tabla CUENTA
	* @return array Retorna un arreglo multidimensional de la forma arreglo[codigo][descrip]
	*/
	function Leo_CUENTA($p_Cuenta)
	{
		$SQL_CUENTA = 'SELECT * FROM admin.cuenta WHERE ct_cta=' . $p_Cuenta . ';';
		return $this->obtenerDatos($SQL_CUENTA);
	}
	
	/**
	* Obtiene de la base los datos del concepto buscado en la opercon
	* @param string $p_TipCom Tipo de comprobante
	* @param string $p_TipCom Operacion
	* @param string $p_Con
	* @return array Retorna un arreglo bidimensional de la forma arreglo[codigo][descrip]
	*/
	function Leo_OPERCON($p_TipCom, $p_Ope, $p_Con)
	{
			$SQL_OPERCON = "SELECT * FROM admin.opercon WHERE oc_tcom='" . $p_TipCom . "' AND oc_ope=" . $p_Ope . " AND oc_conc= '" . $p_Con. "';";
			return $this->obtenerDatos($SQL_OPERCON);
	}
	
	/**
	* Obtiene de la base de datos los datos de la tabla CONCEPTO
	* @return array Retorna un arreglo multidimensional de la forma arreglo[codigo][descrip]
	*/
	function Leo_CONCEPTO($p_Conc)
	{
		$SQL_CONCEPTO = 'SELECT * FROM admin.concepto WHERE co_conc LIKE \'' . $p_Conc . '\';';
		return $this->obtenerDatos($SQL_CONCEPTO);
	}
	
	/**
	* Obtiene de la base de datos los datos de la tabla AUXBAN
	* @return array Retorna un arreglo multidimensional de la forma arreglo[codigo][descrip]
	*/
	function Leo_AUXBAN($p_Banco)
	{
		$SQL_AUXBAN = 'SELECT * FROM admin.auxban WHERE bs_bs LIKE \'' . $p_Banco . '\';';
		return $this->obtenerDatos($SQL_AUXBAN);
	}
	
	/**
	* Obtiene de la base los datos de la operacion buscada segun tipo de comprobante
	* @param string $p_TipCom Tipo de comprobante
	* @param string $p_TipCom Operacion
	* @return array Retorna una Matriz de la forma Matriz[item][campo1][campo2]...[campon]
	*/
	function Leo_OPERAC($p_TipCom, $p_Ope)
	{
		$SQL_OPERAC = "SELECT * FROM admin.operac WHERE op_tcom='" . $p_TipCom . "' AND op_ope=" . $p_Ope . ";";
		
		return $this->obtenerDatos($SQL_OPERAC);
	}
	
	/**
	* Obtiene de la base los datos de la agenda de comprobantes
	* @param num	 $p_Emp		Empresa
	* @param num	 $p_Ent		Entidad
	* @param DATE	 $p_FecEmi	Fecha de emision
	* @param num	 $p_Secu	Secuencia
	* @return array Retorna una Matriz de la forma Matriz[item][campo1][campo2]...[campon]
	*/
	function Leo_AGENCOM($p_Emp, $p_Ent, $p_FecEmi, $p_Sec)
	{
		$SQL_AGENCOM = "SELECT * FROM admin.agencom WHERE age_emp=".$p_Emp." AND age_enti=".$p_Ent." AND age_fecemi='" . $p_FecEmi."' AND age_secu=".$p_Sec.";";
		return $this->obtenerDatos($SQL_AGENCOM);
	}
	

	
	/*---Ayudas----------------------------------------------------------------------------*/
	/**
	* Obtiene de la base de datos la lista de tipos de comprobantes disponibles para ser generados
	* @return array Retorna un arreglo bidimensional de la forma arreglo[codigo][descrip]
	*/
	function TipComDisponibles()
	{
		$SQL_TIPCOM = 'SELECT atc_tcom, atc_dtcom FROM admin.atipcom ORDER BY atc_tcom asc';
		return $this->obtenerDatos($SQL_TIPCOM);
	}
	
	/**
	* Obtiene de la base de datos la lista de cuentas
	* @return array Retorna un arreglo bidimensional de la forma arreglo[codigo][descrip]
	*/
	function CuentasDisponibles()
	{
		$SQL_CUENTAS = 'SELECT ct_cta, ct_dcta FROM admin.cuenta ORDER BY ct_cta asc';
		return $this->obtenerDatos($SQL_CUENTAS);
	}
	
	/**
	* Obtiene de la base de datos la lista de los bancos
	* @return array Retorna un arreglo bidimensional de la forma arreglo[codigo][descrip]
	*/
	function BancosDisponibles()
	{
		$SQL_AUXBAN = 'SELECT bs_bs, bs_dban FROM admin.auxban ORDER BY bs_bs asc';
		return $this->obtenerDatos($SQL_AUXBAN);
	}
	
	/*---Funciones comunes------------------------------------------------------------------*/
	/**
	* Obtiene de la base de datos la cuenta referencial
	* @return array Retorna un arreglo bidimensional de la forma arreglo[codigo][descrip]
	*/
	function Busca_Cuenta_Referencial($p_TipCom, $p_Ope)
	{
/*		SELECT co_cta FROM concepto, opercon
		WHERE co_conc = oc_conc
		AND co_afec = 'R'
		AND co_cfin = 'C'
		AND oc_tcom = 'RC'
		AND oc_ope = 1*/
		
		$SQL_OPERCON = "SELECT co_cta FROM admin.concepto, admin.opercon WHERE co_conc = oc_conc AND
		oc_tcom='" . $p_TipCom . "' AND oc_ope=" . $p_Ope . " AND co_afec= 'R' AND co_cfin='C' ;";
		
		return $this->obtenerDatos($SQL_OPERCON);
	}
	
	/**
	* Obtiene de la base los datos del concepto buscado segun el tipo de operacion del mismo
	* @param string $p_TipCom Tipo de comprobante
	* @param string $p_TipCom Operacion
	* @param string $p_TipOpeCon Tipo de operacion del concepto
	* @return array Retorna un arreglo bidimensional de la forma arreglo[codigo][descrip]
	*/
	function Busca_Concepto_Segun_Tipo($p_TipCom, $p_Ope, $p_TipOpeCon)
	{
		$SQL_OPERCON = "SELECT * FROM admin.opercon WHERE oc_tcom='" . $p_TipCom . "' AND oc_ope=" . $p_Ope . " AND oc_topco= '" . $p_TipOpeCon. "';";
		return $this->obtenerDatos($SQL_OPERCON);
	}
	
	/**
	* Obtiene de la base los datos del concepto buscado segun la caracteristica impositiva
	* @param string $p_TipCom Tipo de comprobante
	* @param string $p_TipCom Operacion
	* @param string $p_CarImp Caracteristica impositiva
	* @return array Retorna un arreglo bidimensional de la forma arreglo[codigo][descrip]
	*/
	function Busca_Concepto_Segun_Caracteristica_Impositiva($p_TipCom, $p_Ope, $p_CarImp)
	{
			$SQL_OPERCON = "SELECT * FROM admin.opercon, admin.concepto WHERE oc_conc=co_conc AND  oc_tcom='" . $p_TipCom . "' AND oc_ope=" . $p_Ope . " AND co_cimp= " . $p_CarImp. ";";
			return $this->obtenerDatos($SQL_OPERCON);
	}
	
	/**
	* Busca una cuenta segun caracteristica financiera.
	* @param string $p_TipCom Tipo de comprobante
	* @param string $p_TipCom Operacion
	* @param string $p_CarFin
	* @return array Retorna un arreglo bidimensional de la forma arreglo[codigo][descrip]
	*/
	function Busca_Cuenta_Segun_CarFin($p_TipCom, $p_Ope, $p_CarFin)
	{
		$SQL_OPERCON = "SELECT * FROM admin.opercon, admin.concepto WHERE oc_conc=co_conc AND  oc_tcom='" . $p_TipCom . "' AND oc_ope=" . $p_Ope . " AND co_cfin='".$p_CarFin."';";
		return $this->obtenerDatos($SQL_OPERCON);
	}
	
	/**
	* Busca deuda de una entidad
	* @param string $p_Empresa Código de Empresa
	* @param string $p_Entidad Código de Entidad
	* @param string $p_Cuenta  Código de Cuenta
	* @return array Retorna un arreglo bidimensional de la forma arreglo[codigo][descrip]
	*/
	function Busca_Deuda($p_Empresa, $p_Entidad, $p_Cuenta)
	{
		$SQL_DETMOV = 
		"SELECT * FROM admin.detmov WHERE dm_emp=".$p_Empresa." AND dm_enti=".$p_Entidad.
		" AND dm_cta LIKE '".$p_Cuenta."' AND dm_cfin='A' AND dm_cope='P'".
		" AND dm_rnmov ISNULL ORDER by dm_emp/*, dm_enti, dm_cta*/;";
		
		return $this->obtenerDatos($SQL_DETMOV);
	}
	
	/**
	* Obtiene de la base de datos la lista operaciones
	* @param string Tipo de comprobante
	* @return array Retorna un arreglo multidimensional: 
	*/
	function OperacionesDisponibles($p_TipCom)
	{
		//El parametro no puede ser vacio
		if(!empty($p_TipCom))
		{
			//'Sanea' la entrada para evitar ataques SQL-Injection
			$TipComSano = $this->sanearTextoSQL($p_TipCom);
			$SQL_OPE = "SELECT op_ope, op_dope FROM admin.operac WHERE op_tcom = " . $TipComSano . "ORDER BY op_ope asc";
		}
		else
		{
			//Si es vacio, genera el warning y devuelvo vacio
			if($this->AppConfig->DEBUG["nivel"] >1)
			{
				$war_msg = "Error en parametros: TipCom";
				trigger_error($war_msg, E_USER_WARNING);
			}
		}
		
		return $this->obtenerDatos($SQL_OPE);
	}
	
	/**
	* Obtiene de la base de datos la lista conceptos relacionados con las operaciones
	* @param string Tipo de comprobante
	* @param string Operacion
	* @return array Retorna un arreglo multidimensional: 
	*/
	function OperConDisponibles($TipCom, $Ope)
	{
		//El parametro no puede ser vacio
		if( !empty($TipCom) && !empty($Ope) )
		{
			//'Sanea' la entrada para evitar ataques SQL-Injection
			$TipComSano = $this->sanearTextoSQL($TipCom);
			//$OpeSano = $this->sanearTextoSQL($Ope);
			
			$SQL_OPERCON = "SELECT oc_conc, oc_dopco FROM admin.opercon WHERE oc_tcom  = " . $TipComSano ." and oc_ope =". $Ope .  " ORDER BY oc_conc asc";
			
		}
		else
		{
			//Si es vacio, genera el warning y devuelvo vacio
			if($this->AppConfig->DEBUG["nivel"] >1)
			{
				$war_msg = "Error en parametros: TipCom";
				trigger_error($war_msg, E_USER_WARNING);
			}
		}
		return $this->obtenerDatos($SQL_OPERCON);
	}
	
	/**
	* Obtiene de la base de datos la lista movimientos
	* @param string Tipo de comprobante
	* @param string Operacion
	* @return array Retorna un arreglo multidimensional: 
	*/
	function CabMovDisponibles($p_Emp, $p_TipCom, $p_Ope)
	{
		//El parametro no puede ser vacio
		if( !empty($p_TipCom) && !empty($p_Ope) && !empty($p_Emp) )
		{
			//'Sanea' la entrada para evitar ataques SQL-Injection
			$TipComSano = $this->sanearTextoSQL($p_TipCom);
			
			$SQL_CABMOV = "SELECT cm_nmov, cm_fmov FROM admin.cabmov WHERE cm_emp=" .$p_Emp . " AND cm_tcom= " . $TipComSano ." AND cm_ope =". $p_Ope .  " ORDER BY cm_nmov asc";
		}
		else
		{
			//Si es vacio, genera el warning y devuelvo vacio
			if($this->AppConfig->DEBUG["nivel"] >1)
			{
				$war_msg = "Error en parametros: TipCom";
				trigger_error($war_msg, E_USER_WARNING);
			}
		}

		return $this->obtenerDatos($SQL_CABMOV);
	}
	
	/**
	* Obtiene de la base de datos la lista de agenda de comprobante
	* @param num	p_Emp		Empresa
	* @param num	p_Ent		Entidad
	* @return array Retorna un arreglo multidimensional
	*/
	function AgenComDisponibles($p_Emp, $p_Ent, $p_Orden)
	{
		if( !empty($p_Emp) && !empty($p_Ent) )
		{
			$SQL_AGENCOM = "SELECT * FROM admin.agencom WHERE age_emp=" .$p_Emp . " AND age_enti= " . $p_Ent;
		 	
		 	if( $p_Orden != '' )
		 		 $SQL_AGENCOM.=" ORDER BY ".$p_Orden;
			
		}
		else
		{
			if($this->AppConfig->DEBUG["nivel"] >1)
			{
				$war_msg = "Error en parametros";
				trigger_error($war_msg, E_USER_WARNING);
			}
		}
		
		return $this->obtenerDatos($SQL_AGENCOM);
	}
	
	/**
	* Obtiene de la base de datos la lista de conceptos disponibles
	* @return array Retorna un arreglo bidimensional de la forma arreglo[codigo][descrip]
	*/
	function ConceptosDisponibles()
	{
			$v_SQL = 'SELECT co_conc, co_dconc FROM admin.concepto ORDER BY co_conc asc';
			return $this->obtenerDatos($v_SQL);
	}
	
	function EstadosDisponibles($p_Cuenta)
	{
			$v_SQL = 'SELECT es_est, es_dest FROM admin.estado WHERE es_cta=\''.$p_Cuenta.'\' ORDER BY es_est asc';
			return $this->obtenerDatos($v_SQL);
	}
	
  //-------------------------------------INTERFAZ PRIVADA-------------------------------------/
	/**
	* Accede a la BD y obtiene los resultados de la consulta identificando si existen errores
	* de conexion o consulta
	* @param string <var>consulta</var> sentencia SQL a enviar a la base de datos
	* @return array Retorna un arreglo bidimensional de la forma arreglo[empresa][descrip]
	*/
	function obtenerDatos(&$consulta)
	{
		//Retorno de la funcion
		$ret_datos = "";
	
		//Para manejar errores
		$NIVEL_DEBUG = $this->AppConfig->DEBUG["nivel"];
		$this->ManejaBD->procesoCorrecto  = true;
		
		$procesoCorrecto = $this->ManejaBD->conectarBD();
		if($procesoCorrecto)
		{
			
			$procesoCorrecto = $this->ManejaBD->consultarBD($consulta);
			if($procesoCorrecto)
			{
				if($NIVEL_DEBUG>2) {
				trigger_error("Consulta realizada: $consulta", E_USER_NOTICE);
				}
				//Obtiene un arreglo asociativo de toda la tabla resultado
				$ret_datos = $this->ManejaBD->obtenerTotalFilasArray();
			}
			else
			{
				if($NIVEL_DEBUG>2) {
				trigger_error($this->DB_QUERY_NULL."(SQL ERRONEO): ".$consulta." XXX", E_USER_NOTICE);
				}
				$this->ManejaBD->procesoCorrecto  = false;
			}
			
			$this->ManejaBD->liberarConsulta();
			$this->ManejaBD->desconectarBD();
		}
		else
		{
			$this->ManejaBD->procesoCorrecto  = false;
			trigger_error("Error:". $this->DB_CONNECT_ERROR, E_USER_ERROR);
			die("Error: ". $this->DB_CONNECT_ERROR);//Podria retornarse un valor especifico que indique error
		}
		
		return $ret_datos;
	}
	
	/**
	*Filtra las cadenas recibidas, que formaran parte e una consulta SQL, para evitar SQL-Injection
	*@param string <var>Texto</var> Texto a filtrar
	*@return string Texto filtrado con los caracteres criticos escapados/eliminados
	*/
	function sanearTextoSQL($texto)
	{
		$ret_sts = "";
	
		if(!empty($texto))
		{
			//Si esta activado MagicQuotes se eliminan todas las contrabarras que escapan comillas (ej: '\"' )
			if (get_magic_quotes_gpc())
			{
				$texto = stripslashes($texto);
			}
		
			//Si el valor NO es numerico, se le agregan comillas simples y se escapan los caracteres criticos
			if (!is_numeric($texto))
			{
				$ret_sts = "'"; //comilla incial
		
				//Chequea si existe la funcion mysql_real_escape_string (PHP >= 4.3) para filtrar el texto
				if (function_exists("mysql_real_escape_string"))
				{
					$ret_sts .= mysql_real_escape_string($texto);
				}
				else
				{
					//Si no existe se agregan contrabarras para escapar posibles comillas
					$ret_sts .= addslashes($texto); //IMPLEMENTAR UNA FUNCION ALTERNATIVA A LA INEXISTENTE
				}
				
				$ret_sts .= "'"; //comilla final
			}
		}
		
		return $ret_sts;
	}
}
?>
