<?php
/*-----------------------------------*
* Proyecto : SAI                    *
* Autor    : Federico A. Ocampo     *
* Desc: Interfaz web de Seleccion   *
*       para Armado de Informes     *
*-----------------------------------*/

//--------------------------------------
require_once 'PostgreClass.php';
require_once "AppConfig.php";
//--------------------------------------


/*****************************************************************************
.::. Clase ObtieneDatos .::.
@Autor:   Federico A. Ocampo
@Email:   federico@mcanet.com.ar
@Empresa: MCAnet
@Descripcion:	Esta clase provee los metodos para obtener, de la base de datos 
				correspondiente, las diferentes tablas. Realiza las consultas 
				necesarias y retorna, por cada consulta, un arreglo con toda la 
				tabla resultado.
*****************************************************************************/
class ObtieneDatosBancos
{
    var $AppConfig;  //Configuracion de la aplicacion
    var $ManejaBD;   //Clase que administra la conexion con la base de datos
    var $DB_CONNECT_ERROR = "FALLO AL CONECTAR CON LA BASE DE DATOS";
    var $DB_QUERY_NULL    = "La consulta no obtuvo resultados";


    /**
    * Constructor: inicializa las propiedades de la clase
    * Recibe todos los parametros por referencia
    * @param AppConfig Objeto con la configuracion de la aplicacion
    * @param ManejadorBD clase para gestionar la conexion con la base de datos
    */
    function ObtieneDatosBancos(&$AppConfig, &$ManejadorBaseDatos)
    {
      $this->AppConfig =& $AppConfig;
      $this->ManejaBD  =& $ManejadorBaseDatos;
    }
	
	
	/**
	* Empieza una transaccion
	* @return array Retorna un arreglo multidimensional de la forma arreglo[codigo][descrip]
	*/
	/*function Begin_Transaction()
	{
		$SQL_BEGIN = 'BEGIN;';
		return $this->obtenerDatos($SQL_BEGIN);
	}*/
	
	/**
	* Termina un bloque de transaccion
	* @return array Retorna un arreglo multidimensional de la forma arreglo[codigo][descrip]
	*/
	/*function End_Transaction()
	{
		$SQL_END = 'COMMIT;';
		return $this->obtenerDatos($SQL_END);
	}*/
	
	/**
	* Vuelve atras las operaciones de un bloque de transaccion
	* @return array Retorna un arreglo multidimensional de la forma arreglo[codigo][descrip]
	*/
	/*function Rollback_Transaction()
	{
		$SQL_END = 'ROLLBACK;';
		return $this->obtenerDatos($SQL_END);
	}*/
	
	/*---Leos------------------------------------------------------------------------------*/
	/**
	* Obtiene de la base de datos los datos de la tabla CABBAN
	* @return array Retorna una Matriz multidimensional de la forma Matriz[`Campo1][Campo2]...[Campon]
	*/
	function Leo_CABBAN($p_Tarjeta, $p_FecEnv, $p_NumTar, $p_Enti)
	{
		$v_SQL = "SELECT * FROM bancos.cabban WHERE cbc_tarjeta=".$p_Tarjeta." AND cbc_fecha='".$p_FecEnv."' AND cbc_numtar='".$p_NumTar."' AND cbc_enti=".$p_Enti;
		return $this->obtenerDatos($v_SQL);
	}
	
	/**
	* Obtiene de la base de datos los datos de la tabla DETBAN
	* @return array Retorna una Matriz multidimensional de la forma Matriz[`Campo1][Campo2]...[Campon]
	*/
	function Leo_DETBAN($p_Tarjeta, $p_FecEnv, $p_NumTar, $p_Refe)
	{
		$v_SQL = "SELECT * FROM bancos.detban WHERE dbc_tarjeta=".$p_Tarjeta." AND dbc_fecha='".$p_FecEnv."' AND dbc_numtar='".$p_NumTar."' AND dbc_enti=".$p_Refe;
		return $this->obtenerDatos($v_SQL);
	}
	
	/*---Ayudas especiales-----------------------------------------------------------------*/
	/**
	* Obtiene de la base de datos la lista de detalle de bancos para una determinada tarjeta
	* @param num	p_Tarjeta
	* @return array Retorna un arreglo multidimensional:
	*/
	function DetalleDeBancos($p_Tarjeta)
	{
//		select dbc_tarjeta||'-'||to_char(date(dbc_fecha), 'dd/mm/yyyy')||'-'||dbc_numtar||'-'||dbc_refe from bancos.detban
		
		$v_SQL = "SELECT '['||to_char(date(cbc_fecha), 'dd/mm/yyyy')||'-'||cbc_numtar||'-'||cbc_enti FROM bancos.cabban WHERE cbc_tarjeta=".$p_Tarjeta." ORDER BY cbc_fecha, cbc_numtar, cbc_enti asc";
		
		return $this->obtenerDatos($v_SQL);
	}
	
	/*---Fucniones especiales-------------------------------------------------------------*/
	/**
	* Borra de la tabla CABBAN los registros correspondientes a la tarjeta.
	* @return array Retorna una Matriz multidimensional de la forma Matriz[`Campo1][Campo2]...[Campon]
	*/
	function BorraCabeceraDeBancos($p_Tarjeta)
	{
		$v_SQL = "DELETE FROM bancos.cabban WHERE cbc_tarjeta=".$p_Tarjeta;
		return $this->obtenerDatos($v_SQL);
	}
	
	/**
	* Borra de la tabla DETBAN los registros correspondientes a la tarjeta.
	* @return array Retorna una Matriz multidimensional de la forma Matriz[`Campo1][Campo2]...[Campon]
	*/
	function BorraDetalleDeBancos($p_Tarjeta)
	{
		$v_SQL = "DELETE FROM bancos.detban WHERE dbc_tarjeta=".$p_Tarjeta;
		return $this->obtenerDatos($v_SQL);
	}
	
  //-------------------------------------INTERFAZ PRIVADA-------------------------------------/
	/**
	* Accede a la BD y obtiene los resultados de la consulta identificando si existen errores
	* de conexion o consulta
	* @param string <var>consulta</var> sentencia SQL a enviar a la base de datos
	* @return array Retorna un arreglo bidimensional de la forma arreglo[empresa][descrip]
	*/
	function obtenerDatos(&$consulta)
	{
		//Retorno de la funcion
		$ret_datos = "";
	
		//Para manejar errores
		$NIVEL_DEBUG = $this->AppConfig->DEBUG["nivel"];
		$this->ManejaBD->procesoCorrecto  = true;
		
		$procesoCorrecto = $this->ManejaBD->conectarBD();
		if($procesoCorrecto)
		{
			$procesoCorrecto = $this->ManejaBD->consultarBD($consulta);
			if($procesoCorrecto)
			{
				if($NIVEL_DEBUG>2) {
				trigger_error("Consulta realizada: $consulta", E_USER_NOTICE);
				}
				//Obtiene un arreglo asociativo de toda la tabla resultado
				$ret_datos = $this->ManejaBD->obtenerTotalFilasArray();
				$this->ManejaBD->procesoCorrecto  = true;
			}
			else
			{
				if($NIVEL_DEBUG>2) {
				trigger_error($this->DB_QUERY_NULL."(NULO): $consulta", E_USER_NOTICE);
				}
				$this->ManejaBD->procesoCorrecto  = false;
			}
			
			$this->ManejaBD->liberarConsulta();
			$this->ManejaBD->desconectarBD();
		}
		else
		{
			trigger_error("Error: Matando proceso". $this->DB_CONNECT_ERROR, E_USER_ERROR);
			$this->ManejaBD->procesoCorrecto  = false;
			die("Error: ". $this->DB_CONNECT_ERROR);//Podria retornarse un valor especifico que indique error
		}
		
		return $ret_datos;
	}
	
	/**
	*Filtra las cadenas recibidas, que formaran parte e una consulta SQL, para evitar SQL-Injection
	*@param string <var>Texto</var> Texto a filtrar
	*@return string Texto filtrado con los caracteres criticos escapados/eliminados
	*/
	function sanearTextoSQL($texto)
	{
		$ret_sts = "";
	
		if(!empty($texto))
		{
			//Si esta activado MagicQuotes se eliminan todas las contrabarras que escapan comillas (ej: '\"' )
			if (get_magic_quotes_gpc())
			{
				$texto = stripslashes($texto);
			}
		
			//Si el valor NO es numerico, se le agregan comillas simples y se escapan los caracteres criticos
			if (!is_numeric($texto))
			{
				$ret_sts = "'"; //comilla incial
		
				//Chequea si existe la funcion mysql_real_escape_string (PHP >= 4.3) para filtrar el texto
				if (function_exists("mysql_real_escape_string"))
				{
					$ret_sts .= mysql_real_escape_string($texto);
				}
				else
				{
					//Si no existe se agregan contrabarras para escapar posibles comillas
					$ret_sts .= addslashes($texto); //IMPLEMENTAR UNA FUNCION ALTERNATIVA A LA INEXISTENTE
				}
				
				$ret_sts .= "'"; //comilla final
			}
		}
		
		return $ret_sts;
	}
}
?>
